@@ -23,6 +23,8 @@
 
 #include <QColorDialog>
 #include <QTimer>
+#include <QStyleFactory>
+#include <QImageReader>
 #include <string>
 #include <iostream>
 #include "mainwindowimpl.h"
@@ -86,7 +88,6 @@ MainWindowImpl::MainWindowImpl(QWidget * parent)
 
     createActions();
     setupMenu();
-    createContextMenu();
 
     loadFormats();
 
@@ -97,6 +98,10 @@ MainWindowImpl::MainWindowImpl(QWidget * parent)
 
     treeWidget->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
 
+    treeWidget->setContextMenuPolicy(Qt::CustomContextMenu);
+    createContextMenu();
+
+
     loadOptions();
 
     resetDisplays();
@@ -156,6 +161,7 @@ void MainWindowImpl::createActions()
 
     connect(actionUncheckItems, SIGNAL(triggered()), treeWidget, SLOT(uncheckItems()));
     connect(actionUncheckAllItems, SIGNAL(triggered()), treeWidget, SLOT(uncheckAllItems()));
+    connect(actionInvertCheckedItems, SIGNAL(triggered()), treeWidget, SLOT(invertCheckAllItems()));
 
     connect(actionRemoveItems, SIGNAL(triggered()), this, SLOT(removeItems()));
     connect(actionRemoveAllItems, SIGNAL(triggered()), this, SLOT(removeAllItems()));
@@ -205,6 +211,9 @@ void MainWindowImpl::setupMenu()
     menu_Edit->addAction(actionCheckAllItems);
     menu_Edit->addAction(actionUncheckItems);
     menu_Edit->addAction(actionUncheckAllItems);
+    menu_Edit->addSeparator();
+    menu_Edit->addAction(actionInvertCheckedItems);
+    menu_Edit->addSeparator();
 
     menu_Actions->addAction(actionConvert);
 
@@ -213,19 +222,25 @@ void MainWindowImpl::setupMenu()
 
 void MainWindowImpl::createContextMenu()
 {
-    QAction *actionSeparator = new QAction(this);
-    actionSeparator->setSeparator(true);
-
     treeWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
     treeWidget->addAction(actionCheckItems);
     treeWidget->addAction(actionCheckAllItems);
     treeWidget->addAction(actionUncheckItems);
     treeWidget->addAction(actionUncheckAllItems);
-    treeWidget->addAction(actionSeparator);
+    addContextMenuSeparator();
+    treeWidget->addAction(actionInvertCheckedItems);
+    addContextMenuSeparator();
     treeWidget->addAction(actionRemoveItems);
     treeWidget->addAction(actionRemoveAllItems);
 }
 
+void MainWindowImpl::addContextMenuSeparator()
+{
+    QAction* separator = new QAction(this);
+    separator->setSeparator(true);
+    treeWidget->addAction(separator);
+}
+
 void MainWindowImpl::openFiles()
 {
     iAList->clear();
@@ -390,11 +405,62 @@ void MainWindowImpl::loadFiles(QStringList fileNames)
         QFileInfo fi(fileNames.at(i));
         ImageAttributes iA;
 
+        int w_data = 0;
+        int h_data = 0;
+        int x_dpi_data = 0;
+        int y_dpi_data = 0;
+
         /* Controlla i doppioni! */
         if (!checkDuplicates(fileNames, i)) {
-            iA.completeFileName = fileNames.at(i).toLocal8Bit();
+            Image my_image;
+            //my_image.quiet(true);
+
+            try {
+                my_image.ping(fileNames.at(i).toStdString());
+
+                w_data = my_image.columns();
+                h_data = my_image.rows();
+                x_dpi_data = my_image.xResolution();
+                y_dpi_data = my_image.yResolution();
+            }
+            catch (Error &error) {
+                QString err_read_status = QString("Error in reading image metadata: %1").arg(QString::fromStdString(error.what()));
+                qWarning() << "Read Error: " << err_read_status;
+                if (Formats::isNativeReadable(fileNames.at(i).toUtf8())) {
+                    QImageReader reader(fileNames.at(i));
+                    QSize size = reader.size();
+                    QImage qimg = reader.read();
+
+                    w_data = size.width();
+                    h_data = size.height();
+
+                    int dpiX = qimg.dotsPerMeterX();
+                    int dpiY = qimg.dotsPerMeterY();
+
+                    x_dpi_data = dpiX * 0.0254;
+                    y_dpi_data = dpiY * 0.0254;
+                }
+            }
+            catch( Magick::WarningCoder &warning )
+            {
+                qWarning() << "Read Warning: " << QString("Warning : %1").arg(QString::fromStdString(warning.what()));;
+            }
+            catch( Magick::Warning &warning )
+            {
+                qWarning() << "Read Warning: " << QString("Warning : %1").arg(QString::fromStdString(warning.what()));;
+            }
+
+            iA.completeFileName = fileNames.at(i).toUtf8();
             iA.fileName = fi.fileName();
             iA.suffix = fi.suffix();
+            iA.imgSize = QString("%1×%2 px").arg(QString::number(w_data), QString::number(h_data));
+            if (x_dpi_data == 0 || y_dpi_data == 0) {
+                iA.imgRes = tr("n/a");
+            } else {
+                iA.imgRes = QString("%1×%2 dpi")
+                                .arg(QString::number(x_dpi_data),
+                                     QString::number(y_dpi_data));
+            }
             iA.size = fi.size();
             iA.path = fi.path();
             iAList->append(iA);   // aggiunge
@@ -408,7 +474,7 @@ bool MainWindowImpl::checkDuplicates(QStringList fileNames, int e)
     int cnt = iAList->count();
 
     for (int i = 0; i < cnt; i++)
-        if (iAList->at(i).completeFileName == fileNames.at(e).toLocal8Bit())
+        if (iAList->at(i).completeFileName == fileNames.at(e).toUtf8())
             return true;
 
     return false;
@@ -726,7 +792,7 @@ void MainWindowImpl::openOutDirectory()
 
 void MainWindowImpl::loadOptions()
 {
-    IniSettings::init();
+    //IniSettings::init();
 
     this->restoreGeometry(IniSettings::windowGeometry());
 
@@ -1143,6 +1209,15 @@ void MainWindowImpl::saveSettings()
     IniSettings::settings->sync();
 }
 
+void MainWindowImpl::loadTheme()
+{
+    QString theme = IniSettings::theme();
+
+    if (theme != "none") {
+        QApplication::setStyle(QStyleFactory::create(theme));
+    }
+}
+
 void MainWindowImpl::overwriteDialog(QString baseName)
 {
     bool ok;
