@@ -55,11 +55,13 @@ public:
     ~MainWindowImpl();
     void importListFromArgv(QString fileName);
     void printSupportedFormats();
+    void loadTheme();
 
 private:
     void createActions();
     void setupMenu();
     void createContextMenu();
+    void addContextMenuSeparator();
     QStringList loadDirectoryFiles(const QString &directory, const QStringList &readableFiltersList, const QDirIterator::IteratorFlag &flag);
     void loadFiles(QStringList fileNames);
     void setFileInList(QString fileName);
@@ -166,6 +168,6 @@ private slots:
     void onlineHelp();
 
     void setRelativeSizeCheckboxes(int state);
-    void setOverwriteStatus(int state);
+    void setOverwriteStatus();
 };
 #endif // MAINWINDOWIMPL_H
